==> ejc-salary-api-3.0.0-20241016.032029-27-sources.jar: com/ejianc/business/salary/vo/TaxModifySaveVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 个税计算-个税调整
 * 
 * @author generator
 * 
 */
public class TaxModifySaveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long taxHoldOrgId; // 个税承担单位id
    private String taxHoldOrgName; // 个税承担单位名称
    private String taxHoldOrgCode; // 个税承担单位编码
    private BigDecimal taxMny; // 个税金额
    private List<TaxModifyVO> jspayableAdjustList = new ArrayList<>(); //


    public Long getTaxHoldOrgId() {
        return taxHoldOrgId;
    }

    public void setTaxHoldOrgId(Long taxHoldOrgId) {
        this.taxHoldOrgId = taxHoldOrgId;
    }

    public String getTaxHoldOrgName() {
        return taxHoldOrgName;
    }

    public void setTaxHoldOrgName(String taxHoldOrgName) {
        this.taxHoldOrgName = taxHoldOrgName;
    }

    public String getTaxHoldOrgCode() {
        return taxHoldOrgCode;
    }

    public void setTaxHoldOrgCode(String taxHoldOrgCode) {
        this.taxHoldOrgCode = taxHoldOrgCode;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public List<TaxModifyVO> getJspayableAdjustList() {
        return jspayableAdjustList;
    }

    public void setJspayableAdjustList(List<TaxModifyVO> jspayableAdjustList) {
        this.jspayableAdjustList = jspayableAdjustList;
    }
}

==> ejc-salary-api-3.0.0-20241210.045551-83-sources.jar: com/ejianc/business/salary/vo/TaxModifySaveVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 个税计算-个税调整
 * 
 * @author generator
 * 
 */
public class TaxModifySaveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long taxHoldOrgId; // 个税承担单位id
    private String taxHoldOrgName; // 个税承担单位名称
    private String taxHoldOrgCode; // 个税承担单位编码
    private BigDecimal taxMny; // 个税金额
    private List<TaxModifyVO> detailList = new ArrayList<>(); //


    public Long getTaxHoldOrgId() {
        return taxHoldOrgId;
    }

    public void setTaxHoldOrgId(Long taxHoldOrgId) {
        this.taxHoldOrgId = taxHoldOrgId;
    }

    public String getTaxHoldOrgName() {
        return taxHoldOrgName;
    }

    public void setTaxHoldOrgName(String taxHoldOrgName) {
        this.taxHoldOrgName = taxHoldOrgName;
    }

    public String getTaxHoldOrgCode() {
        return taxHoldOrgCode;
    }

    public void setTaxHoldOrgCode(String taxHoldOrgCode) {
        this.taxHoldOrgCode = taxHoldOrgCode;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public List<TaxModifyVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<TaxModifyVO> detailList) {
        this.detailList = detailList;
    }
}
